@@ -1,10 +1,11 @@
 
-#' members
-#'
+
 #' Imports data on all current and former Members of Parliament including the Lords and the Commons
-#' @param ID The ID of a member of the House of Commons or the House of Lords. Defaults to NULL. If NULL, returns a data frame of all members. If not NULL, returns a data frame with basic information on that member.
+#' @param ID The ID of a member of the House of Commons or the House of Lords. Defaults to NULL. If NULL, returns a tibble of all members. If not NULL, returns a tibble with basic information on that member.
 #' @param extra_args Additional parameters to pass to API. Defaults to NULL.
-#' @param tidy Fix the variable names in the data frame to remove extra characters, superfluous text and convert variable names to snake_case. Defaults to TRUE.
+#' @param tidy Fix the variable names in the tibble to remove special characters and superfluous text, and converts the variable names to a consistent style. Defaults to TRUE.
+#' @param tidy_style The style to convert variable names to, if tidy = TRUE. Accepts one of 'snake_case', 'camelCase' and 'period.case'. Defaults to 'snake_case'.
+#' @return A tibble with data on members of the House of Commons and/or the House of Lords.
 #' @keywords All Members of Parliament
 #' @export
 #' @examples \dontrun{
@@ -17,7 +18,7 @@
 #' x <- lords_interests(530)
 #'}
 
-members <- function(ID = NULL, extra_args = NULL, tidy = TRUE) {
+members <- function(ID = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
     
     if (is.null(ID) == TRUE) {
         query <- ".json?_pageSize=500"
@@ -43,11 +44,11 @@ members <- function(ID = NULL, extra_args = NULL, tidy = TRUE) {
             pages[[i + 1]] <- mydata$result$items
         }
         
-        df <- dplyr::bind_rows(pages)
+        df <- tibble::as_tibble(dplyr::bind_rows(pages))
         
     } else {
         
-        df <- as.data.frame(members$result$primaryTopic)
+        df <- tibble::as_tibble(members$result$primaryTopic)
         
     }
     
@@ -57,7 +58,7 @@ members <- function(ID = NULL, extra_args = NULL, tidy = TRUE) {
         
         if (tidy == TRUE) {
             
-            df <- hansard_tidy(df)
+            df <- hansard::hansard_tidy(df, tidy_style)
             
             df
             
@@ -75,7 +76,7 @@ members <- function(ID = NULL, extra_args = NULL, tidy = TRUE) {
 #' Imports data on all current and former MPs
 #' @export
 #' @rdname members
-commons_members <- function(extra_args = NULL, tidy = TRUE) {
+commons_members <- function(extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
     
     baseurl <- "http://lda.data.parliament.uk/commonsmembers.json?_pageSize=500"
     
@@ -93,7 +94,7 @@ commons_members <- function(extra_args = NULL, tidy = TRUE) {
         pages[[i + 1]] <- mydata$result$items
     }
     
-    df <- dplyr::bind_rows(pages)
+    df <- tibble::as_tibble(dplyr::bind_rows(pages))
     
     if (nrow(df) == 0) {
         message("The request did not return any data. Please check your search parameters.")
@@ -101,7 +102,7 @@ commons_members <- function(extra_args = NULL, tidy = TRUE) {
         
         if (tidy == TRUE) {
             
-            df <- hansard_tidy(df)
+            df <- hansard::hansard_tidy(df, tidy_style)
             
             df
             
@@ -120,7 +121,7 @@ commons_members <- function(extra_args = NULL, tidy = TRUE) {
 #' Imports data on all current and former peers
 #' @export
 #' @rdname members
-lords_members <- function(extra_args = NULL, tidy = TRUE) {
+lords_members <- function(extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
     
     baseurl <- "http://lda.data.parliament.uk/lordsmembers.json?_pageSize=500"
     
@@ -140,13 +141,15 @@ lords_members <- function(extra_args = NULL, tidy = TRUE) {
     
     df <- dplyr::bind_rows(pages)
     
+    df <- tibble::as_tibble(df)
+    
     if (nrow(df) == 0) {
         message("The request did not return any data. Please check your search parameters.")
     } else {
         
         if (tidy == TRUE) {
             
-            df <- hansard_tidy(df)
+            df <- hansard::hansard_tidy(df, tidy_style)
             
             df
             
@@ -161,10 +164,11 @@ lords_members <- function(extra_args = NULL, tidy = TRUE) {
 
 
 # lords_interests
-#' @param peer_id The ID of a member of the house of lords. If NULL, returns a data frame with all listed financial interests for all members. Defaults to NULL.
+#' @param peer_id The ID of a member of the House of lords. If NULL, returns a tibble with all listed financial interests for all members. Defaults to NULL.
+#' @return A tibble with details on the interests of peers in the House of Lords.
 #' @rdname members
 #' @export
-lords_interests <- function(peer_id = NULL, extra_args = NULL, tidy = TRUE) {
+lords_interests <- function(peer_id = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
     
     if (is.null(peer_id) == TRUE) {
         query <- ".json?_pageSize=500"
@@ -190,13 +194,15 @@ lords_interests <- function(peer_id = NULL, extra_args = NULL, tidy = TRUE) {
     
     df <- dplyr::bind_rows(pages)
     
+    df <- tibble::as_tibble(df)
+    
     if (nrow(df) == 0) {
         message("The request did not return any data. Please check your search parameters.")
     } else {
         
         if (tidy == TRUE) {
             
-            df <- hansard_tidy(df)
+            df <- hansard::hansard_tidy(df, tidy_style)
             
             df
             
@@ -208,7 +214,3 @@ lords_interests <- function(peer_id = NULL, extra_args = NULL, tidy = TRUE) {
         
     }
 }
-
-
-
-
